'use strict';

Object.defineProperty(exports, '__esModule', {
  value: true
});
exports['default'] = logger;

function logger(main) {
  var options = arguments.length <= 1 || arguments[1] === undefined ? {} : arguments[1];
  var _options$logger = options.logger;
  var logger = _options$logger === undefined ? console : _options$logger;
  var _options$collapse = options.collapse;
  var collapse = _options$collapse === undefined ? false : _options$collapse;
  var _options$timestamp = options.timestamp;
  var timestamp = _options$timestamp === undefined ? true : _options$timestamp;

  var loggingColors = {
    request: '#279E39',
    response: '#0065D0'
  };

  var consle = logger;
  var startMessage = collapse ? console.groupCollapsed : console.group;
  var pad = function pad(num, maxLength) {
    return '0'.repeat(maxLength - num.toString().length) + num;
  };

  function groupHeader(from, driverName, color) {
    var time = new Date();
    var formattedTime = timestamp ? '@ ' + pad(time.getHours(), 2) + ':' + pad(time.getMinutes(), 2) + ':' + pad(time.getSeconds(), 2) + '.' + pad(time.getMilliseconds(), 3) : '';
    return ['%c ' + from, 'color: ' + color + '; font-weight: bold', '' + driverName, '' + formattedTime];
  }

  function makeGroupedLog(message, groupHeader) {
    startMessage.apply(console, groupHeader);
    console.log(message);
    console.groupEnd();
  }

  function enableResponseLogging(responses) {
    var _loop = function (driverName) {
      if (responses[driverName].subscribe) {
        responses[driverName].subscribe(function (message) {
          makeGroupedLog(message, groupHeader('response', driverName, loggingColors.response));
        });
      } else if (driverName === 'DOM') {
        responses[driverName].select(':root').observable.subscribe(function (message) {
          makeGroupedLog(message, groupHeader('response', driverName, loggingColors.response));
        });
      }
    };

    for (var driverName in responses) {
      _loop(driverName);
    }
  }

  function enableRequestLogging(requests) {
    var _loop2 = function (driverName) {
      requests[driverName].subscribe(function (message) {
        makeGroupedLog(message, groupHeader('request', driverName, loggingColors.request));
      });
    };

    for (var driverName in requests) {
      _loop2(driverName);
    }
  }

  return function mainWithLogging(responses) {
    var requests = main(responses);
    enableResponseLogging(responses);
    enableRequestLogging(requests);
    return requests;
  };
}

module.exports = exports['default'];